@@ -131,12 +131,17 @@ class Loader:
             self.batch_size = batch_size
             self.n_batches = cc_maths.rint(self.n_samples / self.batch_size)
 
-        self.samples_indexes = np.arange(self.n_samples)
+        # print('self.batch_size =', self.batch_size)
+        # print('self.n_samples =', self.n_samples)
+        # print('self.n_batches =', self.n_batches)
+        # print('self.time.range =', self.time.range)
+        # print('self.n_conditions_directories =', self.n_conditions_directories)
+        # print('self.conditions_directories =', self.conditions_directories)
 
         if self.shuffle:
             self.batches_indexes = None
         else:
-            self.batches_indexes = np.split(self.samples_indexes, self.n_batches, axis=0)
+            self.batches_indexes = np.split(np.arange(self.n_samples), self.n_batches, axis=0)
 
         if self.time.variate_shift:
             self.combinations_directories_no_shift = (
@@ -174,7 +179,7 @@ class Loader:
     def load_batches_e(self):
 
         if self.shuffle:
-            self.batches_indexes = np.split(np.random.permutation(self.samples_indexes), self.n_batches, axis=0)
+            self.batches_indexes = np.split(np.random.permutation(self.n_samples), self.n_batches, axis=0)
         # for b in range(3):
         for b in range(self.n_batches):
             labels_b = self.labels[self.batches_indexes[b]]
