@@ -1,10 +1,11 @@
+# https://stackoverflow.com/questions/22611446/perform-2-sample-t-test
+
 import numpy as np
-# from ccalafiore.array import samples_in_arr1_are_in_arr2, advanced_indexing
-import ccalafiore.stats.descriptive as cc_stats_descriptive
 from scipy.stats import t
 # from scipy.stats.stats import _ttest_finish
-from ccalafiore.combinations import n_conditions_to_combinations
-# https://stackoverflow.com/questions/22611446/perform-2-sample-t-test
+from . import descriptive as cc_stats_descriptive
+from ..combinations import n_conditions_to_combinations
+# from ccalafiore.array import samples_in_arr1_are_in_arr2, advanced_indexing
 
 
 def scores_raw_to_scores_formatted(scores_raw, dtype=None):
